@@ -17,16 +17,10 @@ from .conversion import (
     convert_ts,
     dict2str,
     dt2float,
+    err2str,
     float2dt,
     str2dt,
 )
-from .storing import (
-    load,
-    read_csv,
-    RowReader,
-    save,
-    write_csv,
-)
 from .files import (
     mkdirs,
     rmdirs,
@@ -47,14 +41,27 @@ from .params import (
     read_params,
     DFT,
 )
+from .pprint import (
+    SpeStr,
+    implicit_list,
+)
 from .search import (
     closest,
     previous,
 )
+from .storing import (
+    load,
+    read_csv,
+    RowReader,
+    save,
+    write_csv,
+)
 from .tools import (
     countiter,
     diff,
     display,
+    identity,
+    prod,
     wait_until,
 )
 
